window.Gleam.initSearch([{"doc":"tom","title":"tom","content":"# tom\n\nA Gleam TOML parser!\n\n[![Package Version](https://img.shields.io/hexpm/v/tom)](https://hex.pm/packages/tom)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/tom/)\n\n\n```sh\ngleam add tom\n```\n```gleam\nimport tom\n\nconst config = &quot;\n  [person]\n  name = \\&quot;Lucy\\&quot;\n  is_cool = true\n&quot;\n\npub fn main() {\n  // Parse a string of TOML\n  let assert Ok(parsed) = tom.parse(config)\n\n  // Now you can work with the data directly, or you can use the `get_*`\n  // functions to retrieve values.\n\n  tom.get_string(parsed, [&quot;person&quot;, &quot;name&quot;])\n  // -&gt; Ok(&quot;Lucy&quot;)\n\n  let is_cool = tom.get_bool(parsed, [&quot;person&quot;, &quot;is_cool&quot;])\n  // -&gt; Ok(True)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/tom&gt;.\n\n## Status\n\nThe following string escape sequences are not supported yet:\n\n- `\\xHH`\n- `\\uHHHH`\n- `\\UHHHHHHHH`\n","url":"index.html"},{"doc":"tom","title":"Date","content":"pub type Date {\n  DateValue(year: Int, month: Int, day: Int)\n}\n\nDateValue(year: Int, month: Int, day: Int)\n\n\nSynonyms:\ntom.Date\ntom Date","url":"tom.html#Date"},{"doc":"tom","title":"DateTime","content":"pub type DateTime {\n  DateTimeValue(date: Date, time: Time, offset: Offset)\n}\n\nDateTimeValue(date: Date, time: Time, offset: Offset)\n\n\nSynonyms:\ntom.DateTime\ntom DateTime","url":"tom.html#DateTime"},{"doc":"tom","title":"GetError","content":"pub type GetError {\n  NotFound(key: List(String))\n  WrongType(key: List(String), expected: String, got: String)\n}\n An error that can occur when retrieving a value from a TOML document with\n one of the `get_*` functions.\nNotFound(key: List(String))\n There was no value at the given key.\n\nWrongType(key: List(String), expected: String, got: String)\n The value at the given key was not of the expected type.\n\nSynonyms:\ntom.GetError\ntom GetError","url":"tom.html#GetError"},{"doc":"tom","title":"Number","content":"pub type Number {\n  NumberInt(Int)\n  NumberFloat(Float)\n  NumberInfinity(Sign)\n  NumberNan(Sign)\n}\n A number of any kind, returned by the `get_number` function.\nNumberInt(Int)\n\n\nNumberFloat(Float)\n\n\nNumberInfinity(Sign)\n\n\nNumberNan(Sign)\n\n\nSynonyms:\ntom.Number\ntom Number","url":"tom.html#Number"},{"doc":"tom","title":"Offset","content":"pub type Offset {\n  Local\n  Offset(direction: Sign, hours: Int, minutes: Int)\n}\n\nLocal\n\n\nOffset(direction: Sign, hours: Int, minutes: Int)\n\n\nSynonyms:\ntom.Offset\ntom Offset","url":"tom.html#Offset"},{"doc":"tom","title":"ParseError","content":"pub type ParseError {\n  Unexpected(got: String, expected: String)\n  KeyAlreadyInUse(key: List(String))\n}\n An error that can occur when parsing a TOML document.\nUnexpected(got: String, expected: String)\n An unexpected character was encountered when parsing the document.\n\nKeyAlreadyInUse(key: List(String))\n More than one items have the same key in the document.\n\nSynonyms:\ntom.ParseError\ntom ParseError","url":"tom.html#ParseError"},{"doc":"tom","title":"Sign","content":"pub type Sign {\n  Positive\n  Negative\n}\n\nPositive\n\n\nNegative\n\n\nSynonyms:\ntom.Sign\ntom Sign","url":"tom.html#Sign"},{"doc":"tom","title":"Time","content":"pub type Time {\n  TimeValue(\n    hour: Int,\n    minute: Int,\n    second: Int,\n    millisecond: Int,\n  )\n}\n\nTimeValue(hour: Int, minute: Int, second: Int, millisecond: Int)\n\n\nSynonyms:\ntom.Time\ntom Time","url":"tom.html#Time"},{"doc":"tom","title":"Toml","content":"pub type Toml {\n  Int(Int)\n  Float(Float)\n  Infinity(Sign)\n  Nan(Sign)\n  Bool(Bool)\n  String(String)\n  Date(Date)\n  Time(Time)\n  DateTime(DateTime)\n  Array(List(Toml))\n  ArrayOfTables(List(Dict(String, Toml)))\n  Table(Dict(String, Toml))\n  InlineTable(Dict(String, Toml))\n}\n A TOML document.\nInt(Int)\n\n\nFloat(Float)\n\n\nInfinity(Sign)\n Infinity is a valid number in TOML but Gleam does not support it, so this\n variant represents the infinity values.\n\nNan(Sign)\n NaN is a valid number in TOML but Gleam does not support it, so this\n variant represents the NaN values.\n\nBool(Bool)\n\n\nString(String)\n\n\nDate(Date)\n\n\nTime(Time)\n\n\nDateTime(DateTime)\n\n\nArray(List(Toml))\n\n\nArrayOfTables(List(Dict(String, Toml)))\n\n\nTable(Dict(String, Toml))\n\n\nInlineTable(Dict(String, Toml))\n\n\nSynonyms:\ntom.Toml\ntom Toml","url":"tom.html#Toml"},{"doc":"tom","title":"get","content":"pub fn get(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Toml, GetError)\n Get a value of any type from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = 1&quot;)\n get(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(Int(1))\n \n\nSynonyms:\ntom.get\ntom get","url":"tom.html#get"},{"doc":"tom","title":"get_array","content":"pub fn get_array(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(List(Toml), GetError)\n Get an array from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = [1, 2]&quot;)\n get_array(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok([Int(1), Int(2)])\n \n\nSynonyms:\ntom.get_array\ntom get_array","url":"tom.html#get_array"},{"doc":"tom","title":"get_bool","content":"pub fn get_bool(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Bool, GetError)\n Get a bool from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = true&quot;)\n get_bool(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(True)\n \n\nSynonyms:\ntom.get_bool\ntom get_bool","url":"tom.html#get_bool"},{"doc":"tom","title":"get_date","content":"pub fn get_date(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Date, GetError)\n Get a date from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = 1979-05-27&quot;)\n get_date(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(&quot;1979-05-27&quot;)\n \n\nSynonyms:\ntom.get_date\ntom get_date","url":"tom.html#get_date"},{"doc":"tom","title":"get_date_time","content":"pub fn get_date_time(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(DateTime, GetError)\n Get a date-time from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = 1979-05-27T07:32:00&quot;)\n get_date_time(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(&quot;1979-05-27T07:32:00&quot;)\n \n\nSynonyms:\ntom.get_date_time\ntom get_date_time","url":"tom.html#get_date_time"},{"doc":"tom","title":"get_float","content":"pub fn get_float(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Float, GetError)\n Get a float from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = 1.1&quot;)\n get_float(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(1.1)\n \n\nSynonyms:\ntom.get_float\ntom get_float","url":"tom.html#get_float"},{"doc":"tom","title":"get_int","content":"pub fn get_int(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Int, GetError)\n Get an int from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = 1&quot;)\n get_int(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(1)\n \n\nSynonyms:\ntom.get_int\ntom get_int","url":"tom.html#get_int"},{"doc":"tom","title":"get_number","content":"pub fn get_number(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Number, GetError)\n Get a number of any kind from a TOML document.\n This could be an int, a float, a NaN, or an infinity.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = { d = inf }&quot;)\n get_number(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(NumberInfinity(Positive)))\n \n\nSynonyms:\ntom.get_number\ntom get_number","url":"tom.html#get_number"},{"doc":"tom","title":"get_string","content":"pub fn get_string(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(String, GetError)\n Get a string from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = \\&quot;ok\\&quot;&quot;)\n get_string(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(&quot;ok&quot;)\n \n\nSynonyms:\ntom.get_string\ntom get_string","url":"tom.html#get_string"},{"doc":"tom","title":"get_table","content":"pub fn get_table(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Dict(String, Toml), GetError)\n Get a table from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = { d = 1 }&quot;)\n get_table(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(dict.from_list([#(&quot;d&quot;, Int(1))]))\n \n\nSynonyms:\ntom.get_table\ntom get_table","url":"tom.html#get_table"},{"doc":"tom","title":"get_time","content":"pub fn get_time(\n  toml: Dict(String, Toml),\n  key: List(String),\n) -&gt; Result(Time, GetError)\n Get a time from a TOML document.\n\n ## Examples\n \n \n let assert Ok(parsed) = parse(&quot;a.b.c = 07:32:00&quot;)\n get_time(parsed, [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; Ok(&quot;07:32:00&quot;)\n \n\nSynonyms:\ntom.get_time\ntom get_time","url":"tom.html#get_time"},{"doc":"tom","title":"parse","content":"pub fn parse(\n  input: String,\n) -&gt; Result(Dict(String, Toml), ParseError)\n\nSynonyms:\ntom.parse\ntom parse","url":"tom.html#parse"},{"doc":"tom","title":"tom","content":" A pure Gleam TOML parser!\n\n ```gleam\n import tom\n \n const config = &quot;\n   [person]\n   name = \\&quot;Lucy\\&quot;\n   is_cool = true\n &quot;\n \n pub fn main() {\n   // Parse a string of TOML\n   let assert Ok(parsed) = tom.parse(config)\n \n   // Now you can work with the data directly, or you can use the `get_*`\n   // functions to retrieve values.\n \n   tom.get_string(parsed, [&quot;person&quot;, &quot;name&quot;])\n   // -&gt; Ok(&quot;Lucy&quot;)\n \n   let is_cool = tom.get_bool(parsed, [&quot;person&quot;, &quot;is_cool&quot;])\n   // -&gt; Ok(True)\n }\n ```","url":"tom.html"}]);